#ifndef DISPLAY_H  //     
#define DISPLAY_H

#include "main.h"

// Write data prefix
// 101
#define DAT_WRITE 0x5

// Write command prefix
// 100
#define CMD_WRITE 0x4

// Turn off both system oscillator and LCD bias generator (default)
// 00000000X
#define CMD_SYS_DIS 0x0

// Turn on system oscillator
// 00000001X
#define CMD_SYS_EN 0x2

// Turn off LCD bias generator (default)
// 00000010X
#define CMD_LCD_OFF 0x4

// Turn on LCD bias generator
// 00000011X
#define CMD_LCD_ON 0x6

// Disable time base output
// 00000100X
#define CMD_TIMER_DIS 0x8

// Enable time base output
// 00000110X
#define CMD_TIMER_EN 0xC

// Clear the contents of time base generator
// 000011XXX
#define CMD_TIMER_CLR 0x18

// Enable WDT time-out flag output
// 00000111X
#define CMD_WDT_EN 0xE

// Disable WDT time-out flag output
// 00000101X
#define CMD_WDT_DIS 0xA

// Clear the contents of WDT stage
// 0000111XX
#define CMD_WDT_CLR 0x1C

// Time base/WDT clock output: 1Hz. The WDT time-out flag after: 4s
// 101XX000X
#define CMD_WDT_1_HZ 0x140

// Time base/WDT clock output: 2Hz. The WDT time-out flag after: 2s
// 101XX001X
#define CMD_WDT_2_HZ 0x142

// Time base/WDT clock output: 4Hz. The WDT time-out flag after: 1s
// 101XX010X
#define CMD_WDT_4_HZ 0x144

// Time base/WDT clock output: 8Hz. The WDT time-out flag after: 1/2s
// 101XX011X
#define CMD_WDT_8_HZ 0x146

// Time base/WDT clock output: 16Hz. The WDT time-out flag after: 1/4s
// 101XX100X
#define CMD_WDT_16_HZ 0x148

// Time base/WDT clock output: 32Hz. The WDT time-out flag after: 1/8s
// 101XX101X
#define CMD_WDT_32_HZ 0x14A

// Time base/WDT clock output: 64Hz. The WDT time-out flag after: 1/16s
// 101XX110X
#define CMD_WDT_64_HZ 0x14C

// Time base/WDT clock output: 128Hz. The WDT time-out flag after: 1/32s (default)
// 101XX111X
#define CMD_WDT_128_HZ 0x14E

// Turn off tone outputs (default)
// 00001000X
#define CMD_TONE_OFF 0x10

// Turn on tone outputs
// 00001001X
#define CMD_TONE_ON 0x12

// Tone frequency, 4kHz
// 010XXXXXX
#define CMD_TONE_4K 0x80

// Tone frequency, 2kHz
// 011XXXXXX
#define CMD_TONE_2K 0xC0

// System clock source, crystal oscillator
// 000101XXX
#define CMD_SYS_CLK_XTAL_32K 0x28

// System clock source, on-chip RC oscillator (default)
// 000110XXX
#define CMD_SYS_CLK_RC_256K 0x30

// System clock source, external clock source
// 000111XXX
#define CMD_SYS_CLK_EXT_256K 0x38

// LCD 1/2 bias, 2 commons
// 001000X0X
#define CMD_BIAS_1DIV2_COMMONS_2 0x40

// LCD 1/2 bias, 3 commons
// 001001X0X
#define CMD_BIAS_1DIV2_COMMONS_3 0x48

// LCD 1/2 bias, 4 commons
// 001010X0X
#define CMD_BIAS_1DIV2_COMMONS_4 0x50

// LCD 1/3 bias, 2 commons
// 001000X1X
#define CMD_BIAS_1DIV3_COMMONS_2 0x42

// LCD 1/3 bias, 3 commons
// 001001X1X
#define CMD_BIAS_1DIV3_COMMONS_3 0x4A

// LCD 1/3 bias, 4 commons
// 001010X1X
#define CMD_BIAS_1DIV3_COMMONS_4 0x52

// Disable IRQ output (default)
// 100X0XXXX
#define CMD_IRQ_DIS 0x100

// Enable IRQ output
// 100X1XXXX
#define CMD_IRQ_EN 0x110

// Test mode, user don't use
// 11100000X
#define CMD_TEST_MODE 0x1C0

// Normal mode (default)
// 11100011X
#define CMD_NORMAL_MODE 0x1C6

//  
//
//    AAAA   UP
//   F    B
//   F    B
//   F    B
//    GGGG
//   E    C
//   E    C
//   E    C
//    DDDD   DP
//
//    
#define SEG_A   0
#define SEG_B   1
#define SEG_C   2
#define SEG_D   3
#define SEG_E   4
#define SEG_F   5
#define SEG_G   6
#define SEG_DP  7
#define SEG_UP  8

//   
#define SEG_TOTAL  9

//   
#define POS_TOTAL  11

//    
#define SYM_BLANK	10	// 
#define SYM_MINUS	11	// -
#define SYM_DEGREE	12	// 
#define SYM_A		13	// A
#define SYM_C		14	// c
#define SYM_R		15	// r

//  
void Display_Init (void);
void Display_Clear (void);
void Display_Test (void);
void Display_Write_Cmd (u16 Cmd);
void Display_Write_Data_Single (u8 Address, u8 Data);
void Display_Write_Data_Double (u8 Address, u8 Data);
void Display_Write_Data_All (u8* Data);
void Display_Update (void);
void Display_Sym (u8 pos, u8 c);
void Display_Point (u8 pos, u8 up);
void Display_Num (u8 pos, u32 n);
void Display_SNum (u8 pos, s32 n);

#endif
